<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr">
<context>
    <name>Action</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="188"/>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="489"/>
        <source>Clear log</source>
        <translation>Обриши записник</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="189"/>
        <source>Refresh</source>
        <translation>Освежи</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="539"/>
        <source>Are you sure you want to clear the log?</source>
        <translation>Заиста желите да обришете записник?</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="540"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="541"/>
        <source>Confirm</source>
        <translation>Потврди</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <location filename="../application/filtercontent.cpp" line="80"/>
        <source>All</source>
        <translation>Све</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="83"/>
        <source>Today</source>
        <translation>Данас</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="86"/>
        <source>3 days</source>
        <translation>3 дана</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="89"/>
        <source>1 week</source>
        <translation>седмица</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="92"/>
        <source>1 month</source>
        <translation>1 месец</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="95"/>
        <source>3 months</source>
        <translation>3 месеца</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="224"/>
        <source>Export</source>
        <comment>button</comment>
        <translation>Извези</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <location filename="../application/filtercontent.cpp" line="120"/>
        <source>All</source>
        <translation>Све</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="121"/>
        <source>Emergency</source>
        <translation>Хитно</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="122"/>
        <source>Alert</source>
        <translation>Узбуна</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="123"/>
        <source>Critical</source>
        <translation>Критично</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="124"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="125"/>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="126"/>
        <source>Notice</source>
        <translation>Запажање</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="127"/>
        <source>Info</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="128"/>
        <source>Debug</source>
        <translation>Уклањање грешака</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="198"/>
        <source>Login</source>
        <translation>Пријави се</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="199"/>
        <source>Boot</source>
        <translation>Покретање</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="200"/>
        <source>Shutdown</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="142"/>
        <source>Super critical</source>
        <translation>Веома критично</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="148"/>
        <source>Trace</source>
        <translation>Пратити</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="212"/>
        <source>Identity authentication</source>
        <translation>Identitetna autentifikacija</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="213"/>
        <source>Discretionary Access Control</source>
        <translation>Proizvoljno upravljanje pristupom</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="214"/>
        <source>Mandatory access control</source>
        <translation>Povlačeno upravljanje pristupom</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="215"/>
        <source>Remote</source>
        <translation>Udaljeni</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="216"/>
        <source>Document audit</source>
        <translation>Dokumentni audit</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="217"/>
        <source>Other</source>
        <translation>Ostalo</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="1800"/>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip)</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1794"/>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <location filename="../application/exportprogressdlg.cpp" line="35"/>
        <source>Exporting...</source>
        <translation>Извожење...</translation>
    </message>
    <message>
        <location filename="../application/exportprogressdlg.cpp" line="58"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="3257"/>
        <source>Export successful</source>
        <translation>Успешан извоз</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3260"/>
        <source>Export failed</source>
        <translation>Неуспешан извоз</translation>
    </message>
    <message>
        <location filename="../application/logbackend.cpp" line="1763"/>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>Direktorijum za izvoz nije dostupan. Molim vas da odaberete drugi direktorijum za izvoz operaciju.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="1792"/>
        <source>Export File</source>
        <translation>Извези датотеку</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <location filename="../application/filtercontent.cpp" line="76"/>
        <source>Period:</source>
        <translation>Период:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="114"/>
        <source>Level:  </source>
        <translation>Ниво:  </translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="180"/>
        <source>Status:</source>
        <translation>Стање:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="193"/>
        <source>Event Type:</source>
        <translation>Врста догађаја:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="132"/>
        <source>User:</source>
        <translation>Корисник:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="134"/>
        <source>PID:</source>
        <translation>ПИД:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="138"/>
        <source>Action:</source>
        <translation>Поступак:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="143"/>
        <source>Username:</source>
        <translation>Корисничко име:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="469"/>
        <source>Boot record</source>
        <translation>Евиденција покретања</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="471"/>
        <source>Shutdown record</source>
        <translation>Евиденција искључивања</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="474"/>
        <source>Login record</source>
        <translation>Евиденција пријава</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="208"/>
        <source>Audit Type:</source>
        <translation>Tip auditiranja:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="155"/>
        <source>Application:</source>
        <translation>Aplikacija:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="167"/>
        <source>Submodule:</source>
        <translation>Podmodul:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="201"/>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="202"/>
        <source>Debug</source>
        <translation>Уклањање грешака</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="203"/>
        <source>Info</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="204"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="208"/>
        <source>Emergency</source>
        <translation>Хитно</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="209"/>
        <source>Alert</source>
        <translation>Узбуна</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="210"/>
        <source>Critical</source>
        <translation>Критично</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="213"/>
        <source>Notice</source>
        <translation>Запажање</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="220"/>
        <source>Trace</source>
        <translation>Пратити</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="226"/>
        <source>Super critical</source>
        <translation>Веома критично</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <location filename="../application/logauththread.cpp" line="529"/>
        <source>Log file is empty</source>
        <translation>Датотека записника је празна</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../application/main.cpp" line="329"/>
        <source>Log Viewer</source>
        <translation>Прегледач Записника</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="332"/>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Прегледач Записника је користан алат за приказ записника система.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="120"/>
        <source>No search results</source>
        <translation>Нема резулталта претраге</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="109"/>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="563"/>
        <source>Level</source>
        <translation>Ниво</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="564"/>
        <source>Process</source>
        <translation>Процес</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="565"/>
        <source>Date and Time</source>
        <translation>Датум и време</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="566"/>
        <source>Info</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="567"/>
        <source>User</source>
        <translation>Корисник</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="568"/>
        <source>PID</source>
        <translation>ПИД</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="953"/>
        <source>Source</source>
        <translation>Извор</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="669"/>
        <source>Action</source>
        <translation>Поступак</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3374"/>
        <source>Status</source>
        <translation>Стање</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1140"/>
        <source>Event Type</source>
        <translation>Врста догађаја</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1141"/>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="897"/>
        <source>Level:</source>
        <translation>Ниво:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="898"/>
        <source>Process:</source>
        <translation>Процес:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="899"/>
        <source>Date and Time:</source>
        <translation>Датум и време:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="901"/>
        <source>Info:</source>
        <translation>Подаци:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="902"/>
        <source>Null</source>
        <translation>Нула</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="906"/>
        <source>User:</source>
        <translation>Корисник:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="907"/>
        <source>PID:</source>
        <translation>ПИД:</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3532"/>
        <source>File Name</source>
        <translation>Ime datoteke</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3533"/>
        <source>Time Modified</source>
        <translation>Vreme izmene</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3741"/>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3745"/>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3743"/>
        <source>Core File</source>
        <translation>Koreni fajl</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3744"/>
        <source>User Name </source>
        <translation>Korisničko ime </translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1009"/>
        <source>Offset</source>
        <translation>Pomeraj</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="1142"/>
        <source>Date and Time</source>
        <translation>Датум и време</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <location filename="../application/loglistview.cpp" line="171"/>
        <source>System Log</source>
        <translation>Зап. система</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="182"/>
        <source>Kernel Log</source>
        <translation>Зап. језгра</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="203"/>
        <source>Boot Log</source>
        <translation>Зап. покретања</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="232"/>
        <source>dpkg Log</source>
        <translation>dpkg записник</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="244"/>
        <source>Kwin Log</source>
        <translation>Kwin записник</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="253"/>
        <source>Xorg Log</source>
        <translation>Xorg записник</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="265"/>
        <source>Application Log</source>
        <translation>Зап. програма</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="290"/>
        <source>Boot-Shutdown Event</source>
        <translation>Покре.-Искључ. догађај</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="222"/>
        <source>dnf Log</source>
        <translation>dnf записник</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="303"/>
        <source>Other Log</source>
        <translation>Ostali log</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="339"/>
        <source>Custom Log</source>
        <translation>Prilagođeni log</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="319"/>
        <source>Audit Log</source>
        <translation>Audit log</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="278"/>
        <source>Coredump Log</source>
        <translation>Log korene</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="133"/>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>Nije moguće dobiti informacije o prekidanju, molim vas instalirajte systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="139"/>
        <source>You do not have permission to view it</source>
        <translation>Nemate pristup da pogledate</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="127"/>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>Nivo sigurnosti za trenutni sistem: visok
 audit samo administratori mogu da pregledaju audit log</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3216"/>
        <source>Audit log is not exist.</source>
        <translation>Audit log ne postoji.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="67"/>
        <source>Export logs to the specified path</source>
        <translation>Izvoz logova na zadati put</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="67"/>
        <source>PATH</source>
        <translation>PATH</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="68"/>
        <source>Export logs of specified types</source>
        <translation>Izvoz logova određenih tipova</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="68"/>
        <source>TYPE</source>
        <translation>TYPE</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="69"/>
        <source>Export logs of specified self-developed applications</source>
        <translation>Извлачиње дневника специфичних саморазвијених апликација</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="69"/>
        <source>SELF APPNAME</source>
        <translation>САМ АПЛИКАЦИОН ИМЕ</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="70"/>
        <source>Export logs within a specified time period</source>
        <translation>Извлачиње дневника у задатом временском периоду</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="70"/>
        <source>PERIOD</source>
        <translation>ПЕРИОД</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="71"/>
        <source>Export logs within a specified debug level</source>
        <translation>Извлачиње дневника у задатој нивоу дебага</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="71"/>
        <source>LEVEL</source>
        <translation>НИВО</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="72"/>
        <source>BOOT STATUS</source>
        <translation>СТАТУС ПОГРЕША</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="72"/>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>Извлачиње дневника погреша у задатом стању</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="73"/>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>Извлачиње дневника погреша или аудита у задатом типу догађаја</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="73"/>
        <source>EVENT TYPE</source>
        <translation>ТИП ДОГАЂАЈА</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="74"/>
        <source>Export logs based on keywords search results</source>
        <translation>Извлачиње дневника на основу резултата претраге по кључним речима</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="74"/>
        <source>KEY WORD</source>
        <translation>КЉУЧНА РЕЧ</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="76"/>
        <source>Report coredump informations.</source>
        <translation>Извештај о информацијама кердоумпова.</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="75"/>
        <source>Export logs based on app submodel</source>
        <translation>Извлачиње дневника на основу подмодела апликације</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="75"/>
        <source>SUBMODULE</source>
        <translation>ПОДМОДУЛ</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <location filename="../application/logcollectormain.cpp" line="202"/>
        <source>Refresh interval</source>
        <translation>Интервал освежавања</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="204"/>
        <source>10 sec</source>
        <translation>10 сек</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="205"/>
        <source>1 min</source>
        <translation>1 мин</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="206"/>
        <source>5 min</source>
        <translation>5 мин</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="207"/>
        <source>No refresh</source>
        <translation>Нема освежавања</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="234"/>
        <source>Export All</source>
        <translation>Извлачи све</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="240"/>
        <source>Refresh Now</source>
        <translation>Освежи сада</translation>
    </message>
</context>
</TS>
